# sardine-web

The official web editor plugin for the [sardine-system] library!

## Installation

If you already have sardine-system v0.4.0+ installed or you are fine with
the stable version of Sardine, you can go straight to installing
this package from [PyPI]:

```sh
pip install sardine-web
```

If you do want the Sardine development version, install the repository before
this package following their [installation guide]:

```sh
pip install git+https://github.com/Bubobubobubobubo/sardine
pip install sardine-web
```

If you want to install the development version of *this* repository,
make sure you have [Node.js] and [Yarn] installed:

```sh
pip install git+https://github.com/sardine-system/sardine-web
```

## Usage

Documentation: https://sardine.raphaelforment.fr/editors/fishery.html

This adds a `sardine web` command to Sardine to start the web editor.

[sardine-system]: https://github.com/Bubobubobubobubo/sardine
[PyPI]: https://pypi.org/project/sardine-web/
[installation guide]: https://sardine.raphaelforment.fr/installation.html
[Node.js]: https://nodejs.org/
[Yarn]: https://yarnpkg.com/
